@@ -1,5 +1,6 @@
 //! This module implements parsers for Asciidoc hyperlinks.
 #![allow(dead_code)]
+#![allow(clippy::type_complexity)]
 
 use crate::parser::parse::LABEL_LEN_MAX;
 use crate::parser::Link;
@@ -116,7 +117,7 @@ pub fn adoc_label2dest(i: &str) -> nom::IResult<&str, (Cow<str>, Cow<str>, Cow<s
         ),
     )(i)?;
 
-    if i != "" {
+    if !i.is_empty() {
         let _ = peek::<&str, _, nom::error::Error<_>, _>(nom::character::complete::newline)(i)?;
     };
 
@@ -181,7 +182,7 @@ pub fn adoc_text2label(i: &str) -> nom::IResult<&str, (Cow<str>, Cow<str>)> {
     ))(i)?;
 
     // Check that there is no `[` or `{` following. Do not consume.
-    if i != "" {
+    if !i.is_empty() {
         let _ = nom::character::complete::none_of("[{")(i)?;
     }
 
@@ -207,7 +208,7 @@ fn remove_newline_take_till<'a>(
     move |i: &str| {
         let mut res = Cow::Borrowed("");
         let mut j = i;
-        while j != "" {
+        while !j.is_empty() {
             // `till()` always succeeds. There are two situations, when it does not
             // advance the parser:
             // 1. Input is the empty string `""`.
@@ -217,19 +218,19 @@ fn remove_newline_take_till<'a>(
             // Case 2.: Even if the parser does not advance here, the code below
             // starting with `if let Ok...` it will advance the parser at least
             // one character.
-            let (k, s) =
+            let (k, s1) =
                 nom::bytes::complete::take_till(|c| c == pat || c == '\n' || c == '\\')(j)?;
 
             // Store the result.
             res = match res {
-                Cow::Borrowed("") => Cow::Borrowed(s),
+                Cow::Borrowed("") => Cow::Borrowed(s1),
                 Cow::Borrowed(res_str) => {
                     let mut strg = res_str.to_string();
-                    strg.push_str(s);
+                    strg.push_str(s1);
                     Cow::Owned(strg)
                 }
                 Cow::Owned(mut strg) => {
-                    strg.push_str(s);
+                    strg.push_str(s1);
                     Cow::Owned(strg)
                 }
             };
@@ -383,7 +384,7 @@ fn adoc_parse_curly_bracket_reference(i: &str) -> nom::IResult<&str, Cow<str>> {
             ),
             |s: &str| s.len() <= LABEL_LEN_MAX,
         ),
-        |s| Cow::Borrowed(s),
+        Cow::Borrowed,
     )(i)
 }
 
