@@ -30,7 +30,7 @@ where
 
     output.write_all(begin_doc.as_bytes())?;
     for ((skipped2, consumed2, remaining2), (text2, dest2, title2)) in
-        Hyperlink::new(&input, render_label)
+        Hyperlink::new(input, render_label)
     {
         let skipped = encode_text(skipped2);
         let consumed = encode_text(consumed2);
@@ -38,12 +38,12 @@ where
         let text = encode_safe(&text2).to_string();
         let dest = encode_double_quoted_attribute(&dest2).to_string();
         let title = encode_double_quoted_attribute(&title2).to_string();
-        output.write_all(&verb_renderer(skipped).as_bytes())?;
+        output.write_all(verb_renderer(skipped).as_bytes())?;
         let rendered_link = link_renderer((consumed, (text, dest, title)));
-        output.write_all(&rendered_link.as_bytes())?;
+        output.write_all(rendered_link.as_bytes())?;
         rest = remaining;
     }
-    output.write_all(&verb_renderer(rest).as_bytes())?;
+    output.write_all(verb_renderer(rest).as_bytes())?;
     output.write_all(end_doc.as_bytes())?;
     Ok(())
 }
@@ -178,6 +178,32 @@ where
 /// <a href="https://dest3" title="">:label3: https:&#x2F;&#x2F;dest3</a>
 /// </pre>
 ///
+///
+/// ## Wikitext
+///
+/// ```
+/// use parse_hyperlinks::renderer::text_links2html;
+/// use std::borrow::Cow;
+///
+/// let i = r#"abc[https://dest0 text0]abc
+/// "#;
+///
+/// let expected = "\
+/// <pre>abc<a href=\"https://dest0\" title=\"\">text0</a>abc
+/// </pre>";
+///
+/// let res = text_links2html(i);
+/// assert_eq!(res, expected);
+/// ```
+///
+/// ### Rendered text
+///
+/// This is how the rendered text looks like in the browser:
+///
+/// <pre>abc<a href="https://dest0" title="">text0</a>abc
+/// </pre>
+///
+///
 /// ## HTML
 ///
 /// HTML _inline links_ are sanitized and passed through.
@@ -399,6 +425,31 @@ pub fn text_links2html_writer<'a, S: 'a + AsRef<str>, W: Write>(
 /// <a href="https://dest3" title="">:label3: https://dest3</a>
 /// </pre>
 ///
+///
+/// ## Wikitext
+///
+/// ```
+/// use parse_hyperlinks::renderer::text_rawlinks2html;
+/// use std::borrow::Cow;
+///
+/// let i = r#"abc[https://dest0 text0]abc
+/// "#;
+///
+/// let expected = "\
+/// <pre>abc<a href=\"https://dest0\" title=\"\">[https://dest0 text0]</a>abc
+/// </pre>";
+///
+/// let res = text_rawlinks2html(i);
+/// assert_eq!(res, expected);
+/// ```
+///
+/// ### Rendered text
+///
+/// This is how the rendered text looks like in the browser:
+///
+/// <pre>abc<a href="https://dest0" title="">[https://dest0 text0]</a>abc
+/// </pre>
+///
 /// ## HTML
 ///
 /// HTML _inline links_ are sanitized and their link
@@ -428,7 +479,7 @@ pub fn text_links2html_writer<'a, S: 'a + AsRef<str>, W: Write>(
 /// </pre>
 ///
 #[inline]
-pub fn text_rawlinks2html<'a>(input: &'a str) -> String {
+pub fn text_rawlinks2html(input: &str) -> String {
     let mut output = Vec::new();
     text_rawlinks2html_writer(input, &mut output).unwrap_or_default();
     // We know this is safe, because only `str` have been written into `output`.
@@ -599,6 +650,29 @@ pub fn text_rawlinks2html_writer<'a, S: 'a + AsRef<str>, W: Write>(
 /// <a href="https://dest3" title="">https:&#x2F;&#x2F;dest3</a>
 ///
 ///
+/// ## Wikitext
+///
+/// ```
+/// use parse_hyperlinks::renderer::links2html;
+/// use std::borrow::Cow;
+///
+/// let i = r#"abc[https://dest0 text0]abc
+/// "#;
+///
+/// let expected = "\
+/// <a href=\"https://dest0\" title=\"\">text0</a>
+/// ";
+///
+/// let res = links2html(i);
+/// assert_eq!(res, expected);
+/// ```
+///
+/// ### Rendered text
+///
+/// This is how the rendered text looks like in the browser:
+///
+/// <a href="https://dest0" title="">text0</a>
+///
 ///
 /// ## HTML
 ///
